@@ -6,6 +6,9 @@ PROJECT_NAME = "example"
 # Version of the project
 PROJECT_VERSION = "1.0"
 
+# Enable/Disable debug mode
+DEBUG = True
+
 # Database backend engine
 # Possible value can be either sqlite3, postgresql, mysql, gae
 DATABASE_ENGINE = "sqlite3"
@@ -62,23 +65,38 @@ SESSION_COOKIE = {
     'path': '/'
 }
 
+# Settings for logging. Ignored if DATABASE_ENGINE is 'gae'.
+#
+# The level can be one of 'INFO', 'DEBUG' or 'ERROR'
+# If logfile is not provided, stderr will be assumed.
+LOGGING = {
+    'level': 'DEBUG',
+    'format': '[%(asctime)s] %(levelname)s:%(name)s:%(message)s',
+    'logfile': None,
+}
+
+# Some static links. Useful to provide favicon.ico or robots.txt. You can
+# also provide static directory links to override original static dirs. The
+# paths should be absolute path or relative to the project directory. If you
+# want to specify fallback directories, list them in tuple.
+#
+# For example::
+#
+#    STATIC_LINKS = {
+#        '/static': '/path/to/alternative/static/dir',
+#        '/favicon.ico': 'static/favicon.ico',
+#        '/foo/static': ('/path/to/foo/static1', '/path/to/foo/static2'),
+#    }
+#
+STATIC_LINKS = {
+    '/favicon.ico': 'static/favicon.ico',
+    '/robots.txt': 'static/robots.txt',
+}
+
 # List of installed packages
 INSTALLED_PACKAGES = (
     'kalapy.contrib.sessions',
     'main',
     'wiki',
+    'wiki_extended',
 )
-
-# Package options (submount etc).
-#
-# For example::
-#
-# PACKAGE_OPTIONS = {
-#     'wiki': {'submount': '/wiki'},
-#     'blog': {'submount': '/blog'},
-# }
-#
-PACKAGE_OPTIONS = {
-    'wiki': {'submount': '/wiki'},
-}
-
