@@ -2,8 +2,8 @@
 kalapy.admin.commands.project
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-This module implements `startproject` and `startpackage` commands to
-start a new project or an application package.
+This module implements `project` and `package` commands to new projects
+and packages.
 
 :copyright: (c) 2010 Amit Mendapara.
 :license: BSD, see LINCESE for more details.
@@ -13,13 +13,15 @@ import os, sys, re, shutil, string
 from kalapy.admin import Command, ActionCommand, CommandError
 
 
-def copy_template(template, target, context):
-
-    source = os.path.dirname(os.path.dirname(__file__))
-    source = os.path.join(source, template)
+def copy_helper(source, target, context):
+    """Copy source directory to target directory. Expand the templates with
+    the given context.
+    """
+    if not os.path.isabs(source):
+        source = os.path.join(
+            os.path.dirname(os.path.dirname(__file__)), source)
 
     names = os.listdir(source)
-
     if names and not os.path.exists(target):
         os.mkdir(target)
 
@@ -28,6 +30,10 @@ def copy_template(template, target, context):
         dstname = os.path.join(target, name)
 
         if os.path.isdir(srcname):
+            copy_helper(srcname, dstname, context)
+            continue
+
+        if srcname[-4:] in ('.pyc', '.pyo'):
             continue
 
         if srcname.endswith('_t'):
@@ -46,55 +52,65 @@ def copy_template(template, target, context):
             fo.write(content)
             fo.close()
 
-def check_name(name):
-    pat = re.compile('^[_a-zA-Z]\w*$')
-    if not pat.search(name):
-        raise CommandError("Invalid name '%s'" % name)
+        #XXX: make python scripts executable (pip install issue?)
+        if dstname.endswith('.py') and open(dstname).read(2) == '#!':
+            try:
+                os.chmod(dstname, 0775)
+            except:
+                pass
 
+
+def check_name(name):
+    """Check whether the name is valid name.
+    """
+    if not re.match('^[_a-zA-Z]\w*$', name):
+        raise CommandError("Invalid name '%s'" % name)
     try:
         __import__(name)
-        raise CommandError('name conflicts with existing python module.')
     except ImportError:
-        pass
+        return name
+    else:
+        raise CommandError('name conflicts with an existing python module.')
 
 
 class StartProject(Command):
-    """Create a new KalaPy project.
+    """Create a KalaPy project with the given project name in the current directory.
     """
-    name = "startproject"
+    name = "project"
     usage = "<project>"
 
     scope = None
 
     def execute(self, options, args):
         try:
-            name = args[0]
-        except:
+            name = check_name(args[0])
+        except IndexError:
             self.print_help()
-
-        check_name(name)
+        except CommandError, e:
+            self.error(e)
 
         if options.verbose:
             print "Creating %s..." % name
-        copy_template('project_template', name, {'name': name, 'name_lower': name.lower()})
+        copy_helper('project_template', name, {'name': name, 'name_lower': name.lower()})
 
 
-class StartApp(Command):
-    """start a new package
+class StartPackage(Command):
+    """Create a KalaPy package with the given name in the current directory.
     """
-    name = "startpackage"
+    name = "package"
     usage = "%name <name>"
 
     def execute(self, options, args):
         try:
-            name = args[0]
-        except:
+            name = check_name(args[0])
+        except IndexError:
             self.print_help()
+        except CommandError, e:
+            self.error(e)
 
-        check_name(name)
         if options.verbose:
             print "Creating %s..." % name
-        copy_template('package_template', name, {'name': name})
+        copy_helper('package_template', name, {'name': name})
 
         for d in ('static', 'templates',):
             os.mkdir('%s/%s' % (name, d))
@@ -148,9 +164,9 @@ class GAEProject(ActionCommand):
         from kalapy.conf import settings
         name = settings.PROJECT_NAME
         context = {'appname': name.lower(), 'name': name}
-        if options.verbose:
+        if not os.path.exists('app.yaml') and options.verbose:
             print "Creating app.yaml..."
-        copy_template('gae_template', os.curdir, context)
+        copy_helper('gae_template', os.curdir, context)
 
         if options.install:
             self.install_libs(options, args)
@@ -192,4 +208,3 @@ class GAEProject(ActionCommand):
                 if x in args:
                     os.remove(f)
         os.path.walk("lib", do_clean, ['.pyc', '.pyo', '.so'])
-
